@@ -10,7 +10,7 @@
 ##  - memberserver
 ## exposure: careful
 
-from os import environ
+from os import environ, unlink
 from os.path import exists
 from tempfile import NamedTemporaryFile
 from unittest import TestCase, main, skip, skipUnless
@@ -34,17 +34,18 @@ class FakeUcr:
         self.tmp = None
 
     def __enter__(self):
-        self.tmp = NamedTemporaryFile()
+        self.tmp = open(environ['UNIVENTION_BASECONF'], 'wb')
         self.tmp.write(b'# univention_ base.conf\n\n')
         for key, value in self.values.items():
             self.tmp.write(f'\n{key}: {value}'.encode())
         self.tmp.flush()
-        environ['UNIVENTION_BASECONF'] = self.tmp.name
+        self.tmp.close()
 
     def __exit__(self, exc_type, exc_value, traceback):
+        self.tmp = open(environ['UNIVENTION_BASECONF'], 'wb')
+        for key, value in ucr.items():
+            self.tmp.write(f'\n{key}: {value}'.encode())
         self.tmp.close()
-        self.tmp = None
-        del environ['UNIVENTION_BASECONF']
 
 
 class TestParentDn(TestCase):
@@ -164,7 +165,7 @@ class TestMachineConnection(TestCase):
             with FakeUcr({'server/role': 'memberserver', 'ldap/server/name': 'does.not.exist', 'ldap/server/addition': ' '.join(alt_servers)}):
                 ucr_fake = ConfigRegistry()
                 ucr_fake.load()
-                possible_servers = [ucr_fake.get('ldap/server/name')] + alt_servers
+                possible_servers = [ucr_fake.get('ldap/server/name'), *alt_servers]
                 used_servers = []
                 n = 10
                 min_servers = 3
@@ -187,7 +188,7 @@ class TestMachineConnection(TestCase):
         with FakeUcr({'ldap/server/name': '255.255.255.255', 'ldap/server/addition': ' '.join(alt_servers)}):
             ucr_fake = ConfigRegistry()
             ucr_fake.load()
-            possible_servers = [ucr_fake.get('ldap/server/name')] + alt_servers
+            possible_servers = [ucr_fake.get('ldap/server/name'), *alt_servers]
             used_servers = []
             n = 10
             for _ in range(n):
@@ -291,4 +292,11 @@ class TestAccessUsage(TestCase):
 
 
 if __name__ == '__main__':
-    main()
+
+    tmpfile = NamedTemporaryFile(delete=False)
+    environ['UNIVENTION_BASECONF'] = tmpfile.name
+    with FakeUcr({}):
+        main()
+    del environ['UNIVENTION_BASECONF']
+    tmpfile.close()
+    unlink(tmpfile.name)
