@@ -17,8 +17,7 @@ from subprocess import Popen
 from sys import exit
 from tempfile import mkdtemp
 from time import sleep
-from types import TracebackType
-from typing import Dict, List, Type
+from typing import TYPE_CHECKING
 
 from univention.config_registry.frontend import handler_set
 from univention.testing.ucr import UCSTestConfigRegistry
@@ -26,6 +25,10 @@ from univention.testing.udm import UCSTestUDM
 from univention.testing.utils import verify_ldap_object
 
 
+if TYPE_CHECKING:
+    from types import TracebackType
+
+
 MODULE = 'container/ou'
 UNIQUE = 'ucs-test38823'
 TMPDIR = '/tmp'
@@ -42,7 +45,7 @@ class Environment:
         ent = getpwnam(USERID)
         self.uid = ent.pw_uid
 
-    def __enter__(self) -> Environment:  # noqa: PYI034
+    def __enter__(self) -> Environment:
         self.tmpdir = mkdtemp(prefix='ucs-test', dir=TMPDIR)
         print('I: tmpdir=%r' % (self.tmpdir,))
         chown(self.tmpdir, self.uid, -1)
@@ -66,14 +69,14 @@ class Environment:
                     line = 'TMPDIR = %r\n' % (self.tmpdir,)
                 target.write(line)
 
-    def __exit__(self, exc_type: Type[BaseException] | None, exc_value: BaseException | None, traceback: TracebackType | None) -> None:
+    def __exit__(self, exc_type: type[BaseException] | None, exc_value: BaseException | None, traceback: TracebackType | None) -> None:
         rmtree(self.tmpdir, ignore_errors=True)
         self.tmpdir = None
 
 
 class Listener:
 
-    def __init__(self, ucr: Dict[str, str], env: Environment) -> None:
+    def __init__(self, ucr: dict[str, str], env: Environment) -> None:
         self.ucr = ucr
         self.env = env
         self.proc = None
@@ -88,16 +91,13 @@ class Listener:
             '-y', '/etc/machine.secret',
         ]
 
-    def __enter__(self) -> Listener:  # noqa: PYI034
+    def __enter__(self) -> Listener:
         self.init_listener()
         self.run_listener()
         return self
 
     def init_listener(self) -> None:
-        cmd = self.cmd + [
-            '-d', '2',
-            '-i',
-        ]
+        cmd = [*self.cmd, '-d', '2', '-i']
         proc = Popen(cmd, close_fds=True)
         print('I: %d = %r' % (proc.pid, cmd))
         ret = proc.wait()
@@ -106,15 +106,12 @@ class Listener:
             exit(ret)
 
     def run_listener(self) -> Listener:
-        cmd = self.cmd + [
-            '-d', '4',
-            '-F',
-        ]
+        cmd = [*self.cmd, '-d', '4', '-F']
         self.proc = Popen(cmd, close_fds=True)
         print('I: %d = %r' % (self.proc.pid, cmd))
         return self
 
-    def __exit__(self, exc_type: Type[Exception] | None, exc_value: BaseException | None, traceback: TracebackType | None) -> None:  # noqa: PYI036
+    def __exit__(self, exc_type: type[Exception] | None, exc_value: BaseException | None, traceback: TracebackType | None) -> None:  # noqa: PYI036
         if not exc_type:
             self.wait_transactions()
         self.kill_listener()
@@ -196,7 +193,7 @@ def main() -> None:
     exit(1 if error else 0)
 
 
-def unexpected_transactions(env: Environment, ucr: Dict[str, str]) -> bool:
+def unexpected_transactions(env: Environment, ucr: dict[str, str]) -> bool:
     found_add = False
     found_modify = False
     found_other = False
@@ -212,14 +209,14 @@ def unexpected_transactions(env: Environment, ucr: Dict[str, str]) -> bool:
             elif line == repr((dn, True, False, 'm')):
                 print('I: Found modify: %s' % (line,))
                 found_modify = True
-            elif eval(line)[0].endswith(dn):  # noqa: PGH001, S307
+            elif eval(line)[0].endswith(dn):  # noqa: S307
                 found_other = True
                 print('E: Found other: %s' % (line,))
 
     return found_other or not found_add or not found_modify
 
 
-def is_not_in_cache(env: Environment, ucr: Dict[str, str]) -> bool:
+def is_not_in_cache(env: Environment, ucr: dict[str, str]) -> bool:
     error = False
 
     dn = 'dn: ou=%s,%s' % (UNIQUE, ucr['ldap/base'])
@@ -246,7 +243,7 @@ def is_not_in_cache(env: Environment, ucr: Dict[str, str]) -> bool:
     return error
 
 
-def handler(dn: str, new: Dict[str, List[bytes]], old: Dict[str, List[bytes]], cmd: str = '') -> None:
+def handler(dn: str, new: dict[str, list[bytes]], old: dict[str, list[bytes]], cmd: str = '') -> None:
     with open(join(TMPDIR, UNIQUE), 'a') as log:
         print(repr((dn, bool(new), bool(old), cmd)), file=log)
 
