@@ -48,13 +48,13 @@ class Configuring:
 
     def __exit__(self, exc_type, exc_val, exc_tb):
         if self.revert == 'configure':
-            config = {key: None for key in self.settings}  # noqa: RUF025
+            config = {key: None for key in self.settings}  # noqa: C420
             configure = get_action('configure')
             configure.call(app=self.app, set_vars=config, run_script='no')
             for setting in self.settings:
                 assert ucr_get(setting) is None
         elif self.revert == 'ucr':
-            config = {key: None for key in self.settings}  # noqa: RUF025
+            config = {key: None for key in self.settings}  # noqa: C420
             ucr_save(config)
 
 
@@ -146,7 +146,7 @@ UCSOverviewCategory = False'''
     return Apps().find('apache')
 
 
-@pytest.fixture()
+@pytest.fixture
 def installed_apache_docker_app(apache_docker_app):
     with install_app(apache_docker_app) as app:
         yield app
