@@ -27,24 +27,24 @@ if TYPE_CHECKING:
     from collections.abc import Iterable
 
 
-@pytest.fixture()
+@pytest.fixture
 def udm():
     with udm_test.UCSTestUDM() as udm:
         yield udm
 
 
-@pytest.fixture()
+@pytest.fixture
 def ucr():
     with ucr_test.UCSTestConfigRegistry() as ucr:
         yield ucr
 
 
-@pytest.fixture()
+@pytest.fixture
 def user_addr():
     return random_email()
 
 
-@pytest.fixture()
+@pytest.fixture
 def fqdn():
     with ucr_test.UCSTestConfigRegistry() as ucr:
         return '%(hostname)s.%(domainname)s' % ucr
