@@ -14,7 +14,7 @@ import subprocess
 import sys
 from datetime import datetime, timedelta
 from time import sleep
-from typing import Iterator, List, Sequence, Tuple
+from typing import TYPE_CHECKING
 
 from univention.config_registry import ucr
 from univention.testing import utils
@@ -22,6 +22,10 @@ from univention.testing.codes import Reason
 from univention.testing.strings import random_username
 
 
+if TYPE_CHECKING:
+    from collections.abc import Iterator, Sequence
+
+
 LOCKOUT_DURATION = 1  # duration of lockout in minutes
 LOCKOUT_THRESHOLD = 3  # amount of auth. attempts allowed before the lock out
 TEST_USER_PASS = 'Univention1'
@@ -39,7 +43,7 @@ def remove_samba_warnings(input_str: str) -> str:
     return input_str.replace('NOTE: Service IPC$ is flagged unavailable.', '').strip()
 
 
-def create_and_run_process(cmd: Sequence[str]) -> Tuple[str, str]:
+def create_and_run_process(cmd: Sequence[str]) -> tuple[str, str]:
     """
     Create a process as a Popen instance with a given 'cmd'
     and 'communicates' with it. Returns (stdout, stderr).
@@ -48,7 +52,7 @@ def create_and_run_process(cmd: Sequence[str]) -> Tuple[str, str]:
     return remove_samba_warnings(proc.stdout), remove_samba_warnings(proc.stderr)
 
 
-def try_to_authenticate(password: str) -> Tuple[str, str]:
+def try_to_authenticate(password: str) -> tuple[str, str]:
     """
     Authenticate 'test_username' user with given 'password'
     using smbclient and execute an 'ls'. Returns (stdout, stderr).
@@ -191,7 +195,7 @@ def main() -> None:
         create_delete_test_user(True)
 
         set_lockout_settings(LOCKOUT_DURATION, LOCKOUT_THRESHOLD)
-        hist: List[str] = []
+        hist: list[str] = []
         hist += dump_pwpolicy()
 
         print("# Twiddling thumbs for 30s")  # Why?
