@@ -62,9 +62,7 @@ def test_group_sync_from_udm_to_ad_with_rename(group_class, sync_mode):
         adconnector.wait_for_sync()
 
         AD.verify_object(ad_group_dn, None)
-        ad_group_dn = ldap.dn.dn2str([
-            [("CN", udm_group.to_unicode(udm_group.rename).get("name"), ldap.AVA_STRING)],
-            [("CN", "groups", ldap.AVA_STRING)]] + ldap.dn.str2dn(AD.adldapbase))
+        ad_group_dn = ldap.dn.dn2str([[("CN", udm_group.to_unicode(udm_group.rename).get("name"), ldap.AVA_STRING)], [("CN", "groups", ldap.AVA_STRING)], *ldap.dn.str2dn(AD.adldapbase)])
         AD.verify_object(ad_group_dn, tcommon.map_udm_group_to_con(udm_group.rename))
 
         delete_udm_group(udm, AD, udm_group_dn, ad_group_dn, adconnector.wait_for_sync)
@@ -84,9 +82,7 @@ def test_group_sync_from_udm_to_ad_with_move(group_class, sync_mode):
 
         adconnector.wait_for_sync()
         AD.verify_object(ad_group_dn, None)
-        ad_group_dn = ldap.dn.dn2str([
-            [("CN", udm_group.to_unicode(udm_group.group).get("name"), ldap.AVA_STRING)],
-            [("CN", udm_group.container, ldap.AVA_STRING)]] + ldap.dn.str2dn(AD.adldapbase))
+        ad_group_dn = ldap.dn.dn2str([[("CN", udm_group.to_unicode(udm_group.group).get("name"), ldap.AVA_STRING)], [("CN", udm_group.container, ldap.AVA_STRING)], *ldap.dn.str2dn(AD.adldapbase)])
         AD.verify_object(ad_group_dn, tcommon.map_udm_group_to_con(udm_group.group))
 
         delete_udm_group(udm, AD, udm_group_dn, ad_group_dn, adconnector.wait_for_sync)
@@ -116,9 +112,7 @@ def test_group_sync_from_ad_to_udm_with_rename(group_class, sync_mode):
         adconnector.wait_for_sync()
 
         tcommon.verify_udm_object("groups/group", udm_group_dn, None)
-        udm_group_dn = ldap.dn.dn2str([
-            [("CN", udm_group.to_unicode(udm_group.rename).get("name"), ldap.AVA_STRING)],
-            [("CN", "groups", ldap.AVA_STRING)]] + ldap.dn.str2dn(tcommon.configRegistry['ldap/base']))
+        udm_group_dn = ldap.dn.dn2str([[("CN", udm_group.to_unicode(udm_group.rename).get("name"), ldap.AVA_STRING)], [("CN", "groups", ldap.AVA_STRING)], *ldap.dn.str2dn(tcommon.configRegistry["ldap/base"])])
         tcommon.verify_udm_object("groups/group", udm_group_dn, udm_group.rename)
 
         delete_con_group(AD, ad_group_dn, udm_group_dn, adconnector.wait_for_sync)
@@ -139,9 +133,7 @@ def test_group_sync_from_ad_to_udm_with_move(group_class, sync_mode):
         adconnector.wait_for_sync()
 
         tcommon.verify_udm_object("groups/group", udm_group_dn, None)
-        udm_group_dn = ldap.dn.dn2str([
-            [("CN", udm_group.to_unicode(udm_group.group).get("name"), ldap.AVA_STRING)],
-            [("CN", udm_group.container, ldap.AVA_STRING)]] + ldap.dn.str2dn(tcommon.configRegistry['ldap/base']))
+        udm_group_dn = ldap.dn.dn2str([[("CN", udm_group.to_unicode(udm_group.group).get("name"), ldap.AVA_STRING)], [("CN", udm_group.container, ldap.AVA_STRING)], *ldap.dn.str2dn(tcommon.configRegistry["ldap/base"])])
         tcommon.verify_udm_object("groups/group", udm_group_dn, udm_group.group)
 
         delete_con_group(AD, ad_group_dn, udm_group_dn, adconnector.wait_for_sync)
