@@ -202,6 +202,7 @@ def portal_config(ucr_proper: ConfigRegistry) -> SimpleNamespace:
 
 @pytest.fixture
 def keycloak_config(ucr_proper: ConfigRegistry) -> SimpleNamespace:
+    udm_fqdn = f"{ucr_proper['hostname']}.{ucr_proper['domainname']}"
     url = run_command(['univention-keycloak', 'get-keycloak-base-url']).rstrip()
     server = urlparse(url).netloc
     path = urlparse(url).path
@@ -210,6 +211,7 @@ def keycloak_config(ucr_proper: ConfigRegistry) -> SimpleNamespace:
         'server': server,
         'path': path,
         'url': os.path.join(url, ''),  # we need a trailing / here, see keycloak apache proxy config
+        'udm_endpoint': f'https://{udm_fqdn}/univention/udm',
         'admin_url': f'{url}/admin',
         'token_url': f'{url}/realms/ucs/protocol/openid-connect/token',
         'logout_url': f'{url}/realms/ucs/protocol/openid-connect/logout',
