@@ -2,7 +2,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2017-2024 Univention GmbH
+# Copyright 2017-2025 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -86,7 +86,7 @@ class _HTTPType(type):
             HTTPError.codes[mcs.code] = mcs
         except (NameError, AttributeError):
             pass
-        return type.__init__(mcs, name, bases, dict)
+        type.__init__(mcs, name, bases, dict)
 
 
 class ConnectionError(Exception):
