@@ -5,7 +5,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2023-2024 Univention GmbH
+# Copyright 2023-2025 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -277,6 +277,7 @@ class UMCBrowserTest(Interactions):
         login_should_fail: bool = False,
         do_navigation: bool = True,
         expect_password_change_prompt: bool = False,
+        wait_until: str = 'networkidle',
     ):
         """
         Navigates to {base_url}/univention/login?location={location} and logs in with the given credentials
@@ -321,7 +322,7 @@ class UMCBrowserTest(Interactions):
             login_button.click()
 
         # TODO: wait_until networkidle is discouraged by Playwright, replace at some point
-        self.page.wait_for_url(re.compile(r'.*univention/(management|portal|selfservice).*'), wait_until='networkidle')
+        self.page.wait_for_url(re.compile(r'.*univention/(management|portal|selfservice).*'), wait_until=wait_until)
         logging.info('Login Done')
 
     def end_umc_session(self):
