@@ -1,7 +1,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# SPDX-FileCopyrightText: 2024 Univention GmbH
+# SPDX-FileCopyrightText: 2024-2025 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 
 """Format UCS Test results as simple text report."""
@@ -25,7 +25,7 @@ __all__ = ['Raw', 'Text']
 class _Term:  # pylint: disable-msg=R0903
     """Handle terminal formatting."""
 
-    __ANSICOLORS = "BLACK RED GREEN YELLOW BLUE MAGENTA CYAN WHITE".split()
+    __ANSICOLORS = ["BLACK", "RED", "GREEN", "YELLOW", "BLUE", "MAGENTA", "CYAN", "WHITE"]
     # vt100.sgr0 contains a delay in the form of '$<2>'
     __RE_DELAY = re.compile(br'\$<\d+>[/*]?')
 
